==> gimp-2.3.10.tar.bz2: gimp-2.3.10/app/core/gimpimage-convert.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_CONVERT_H__
#define __GIMP_IMAGE_CONVERT_H__


#define MAXNUMCOLORS 256


void   gimp_image_convert          (GimpImage              *image,
                                    GimpImageBaseType       new_type,
                                    /* The following params used only for
                                     * new_type == GIMP_INDEXED
                                     */
                                    gint                    num_cols,
                                    GimpConvertDitherType   dither,
                                    gboolean                alpha_dither,
                                    gboolean                remove_dups,
                                    GimpConvertPaletteType  palette_type,
                                    GimpPalette            *custom_palette,
                                    GimpProgress           *progress);


#endif  /*  __GIMP_IMAGE_CONVERT_H__  */

==> gimp-2.3.11.tar.bz2: gimp-2.3.11/app/core/gimpimage-convert.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_CONVERT_H__
#define __GIMP_IMAGE_CONVERT_H__


#define MAXNUMCOLORS 256


void   gimp_image_convert          (GimpImage              *image,
                                    GimpImageBaseType       new_type,
                                    /* The following params used only for
                                     * new_type == GIMP_INDEXED
                                     */
                                    gint                    num_cols,
                                    GimpConvertDitherType   dither,
                                    gboolean                alpha_dither,
                                    gboolean                remove_dups,
                                    GimpConvertPaletteType  palette_type,
                                    GimpPalette            *custom_palette,
                                    GimpProgress           *progress);

void gimp_image_convert_set_dither_matrix (gint             width,
                                           gint             height,
                                           guchar          *source);


#endif  /*  __GIMP_IMAGE_CONVERT_H__  */
